@@ -91,6 +91,28 @@ class RemoteUploaderDownloader(LoggerDestination):
             loggers=[remote_uploader_downloader],
         )
 
+    or
+
+    .. testcode:: composer.loggers.remote_uploader_downloader.RemoteUploaderDownloader.__init__
+        from composer.loggers import RemoteUploaderDownloader
+        from composer.trainer import Trainer
+
+        remote_uploader_downloader = RemoteUploaderDownloader(
+            bucket_uri="libcloud://my-gcs-bucket",
+            backend_kwargs={
+                "provider": "google_storage",
+                "container": "my-gcs-bucket",
+                "key_environ": "MY_HMAC_ACCESS_ID", # Name of env variable for HMAC access id.
+                "secret_environ": "MY_HMAC_SECRET", # Name of env variable for HMAC secret.
+            },
+        )
+
+        # Construct the trainer using this logger
+        trainer = Trainer(
+            ...,
+            loggers=[remote_uploader_downloader],
+        )
+
     .. note::
 
         This callback blocks the training loop to upload each file, as
