@@ -1,7 +1,7 @@
 # Copyright 2022 MosaicML Composer authors
 # SPDX-License-Identifier: Apache-2.0
 
-"""`YAHP <https://docs.mosaicml.com/projects/yahp/en/stable/README.html>`_ interface for :class:`.MNIST_Classifier`."""
+"""`YAHP <https://docs.mosaicml.com/projects/yahp/en/stable/README.html>`_ interface for :func:`.mnist_model`."""
 
 from dataclasses import asdict, dataclass
 
@@ -12,7 +12,7 @@ __all__ = ['MnistClassifierHparams']
 
 @dataclass
 class MnistClassifierHparams(ModelHparams):
-    """`YAHP <https://docs.mosaicml.com/projects/yahp/en/stable/README.html>`_ interface for :class:`.MNIST_Classifier`.
+    """`YAHP <https://docs.mosaicml.com/projects/yahp/en/stable/README.html>`_ interface for :func:`.mnist_model`.
 
     Args:
         num_classes (int, optional): The number of classes. Needed for classification tasks. Default: 10.
@@ -20,5 +20,5 @@ class MnistClassifierHparams(ModelHparams):
     """
 
     def initialize_object(self):
-        from composer.models import MNIST_Classifier
-        return MNIST_Classifier(**asdict(self))
+        from composer.models import mnist_model
+        return mnist_model(**asdict(self))
