@@ -11,7 +11,7 @@ from __future__ import annotations
 
 import logging
 import math
-from typing import Iterable, List, Tuple
+from typing import Iterable, List, Tuple, Union
 
 import torch
 from torch.optim import SGD, AdamW
@@ -25,26 +25,50 @@ __all__ = ['DecoupledSGDW', 'DecoupledAdamW']
 class DecoupledSGDW(SGD):
     """SGD optimizer with the weight decay term decoupled from the learning rate.
 
+    NOTE: Since `weight_decay` is no longer scaled by `lr`, you will likely want to use much smaller values
+    for `weight_decay` than you would if using `torch.optim.SGD`. In this optimizer, the value `weight_decay` translates exactly to:
+    'On every optimizer update, every weight element will be multiplied by `(1.0 - weight_decay_t)`'.
+    The term `weight_decay_t` will follow the same schedule as `lr_t` but crucially will not be scaled by `lr`.
+
     Argument defaults are copied from :class:`torch.optim.SGD`.
 
-    The standard `SGD <https://pytorch.org/docs/stable/generated/torch.optim.SGD.html?highlight=sgd#torch.optim.SGD>`_
+    Why use this optimizer? The standard `SGD <https://pytorch.org/docs/stable/generated/torch.optim.SGD.html?highlight=sgd#torch.optim.SGD>`_
     optimizer couples the weight decay term with the gradient calculation. This ties the optimal value
     of :attr:`weight_decay` to :attr:`lr` and can also hurt generalization in practice. For more details
     on why decoupling might be desirable, see `Decoupled Weight Decay Regularization <https://arxiv.org/abs/1711.05101>`_.
 
     Args:
-        params (list): List of parameters to optimize or dicts defining parameter groups.
-        lr (float, optional): Learning rate.
+        params (iterable): Iterable of parameters to optimize or dicts defining parameter groups.
+        lr (float): Learning rate.
         momentum (int, optional): Momentum factor. Default: ``0``.
         dampening (int, optional): Dampening factor applied to the momentum. Default: ``0``.
         weight_decay (int, optional): Decoupled weight decay factor. Default: ``0``.
         nesterov (bool, optional): Enables Nesterov momentum updates. Default: ``False``.
     """
 
+    def __init__(self,
+                 params: Union[Iterable[torch.Tensor], Iterable[dict]],
+                 lr: float = required,
+                 momentum: float = 0,
+                 dampening: float = 0,
+                 weight_decay: float = 0,
+                 nesterov: bool = False):
+        if weight_decay >= 1e-3:
+            log.warning(
+                f'You are using a high value of `weight_decay={weight_decay}` for the `DecoupledSGDW` optimizer. Are you sure you want to do this? '
+                f'Your model\'s weights will be multiplied by {1.0 - weight_decay} on every step!')
+        super().__init__(params=params,
+                         lr=lr,
+                         momentum=momentum,
+                         dampening=dampening,
+                         weight_decay=weight_decay,
+                         nesterov=nesterov)
+        for group in self.param_groups:
+            group['initial_lr'] = group['lr']
+
     @staticmethod
-    def sgdw(params: Iterable[torch.nn.parameter.Parameter], d_p_list: List[torch.Tensor],
-             momentum_buffer_list: List[torch.Tensor], *, weight_decay: float, momentum: float, lr: float,
-             initial_lr: float, dampening: float, nesterov: bool):
+    def sgdw(params: List[torch.Tensor], d_p_list: List[torch.Tensor], momentum_buffer_list: List[torch.Tensor], *,
+             weight_decay: float, momentum: float, lr: float, initial_lr: float, dampening: float, nesterov: bool):
         r"""Functional API that performs SGDW algorithm computation.
 
         Args:
@@ -77,22 +101,11 @@ class DecoupledSGDW(SGD):
                     d_p = buf
 
             if weight_decay != 0:
-                decay_factor = lr / initial_lr
+                decay_factor = (lr / initial_lr) if initial_lr else 1.0
                 param.mul_(1 - decay_factor * weight_decay)
 
             param.add_(d_p, alpha=-lr)
 
-    def __init__(self,
-                 params: List[torch.Tensor],
-                 lr: float = required,
-                 momentum: float = 0,
-                 dampening: float = 0,
-                 weight_decay: float = 0,
-                 nesterov: bool = False):
-        super().__init__(params, lr, momentum, dampening, weight_decay, nesterov)
-        for group in self.param_groups:
-            group['initial_lr'] = group['lr']
-
     @torch.no_grad()
     def step(self, closure=None):
         """Performs a single optimization step.
@@ -149,23 +162,45 @@ class DecoupledSGDW(SGD):
 class DecoupledAdamW(AdamW):
     """Adam optimizer with the weight decay term decoupled from the learning rate.
 
-    Argument defaults are copied from :class:`torch.optim.AdamW`.
+    NOTE: Since `weight_decay` is no longer scaled by `lr`, you will likely want to use much smaller values
+    for `weight_decay` than you would if using `torch.optim.Adam` or `torch.optim.AdamW`. In this optimizer, the value `weight_decay` translates exactly to:
+    'On every optimizer update, every weight element will be multiplied by `(1.0 - weight_decay_t)`'.
+    The term `weight_decay_t` will follow the same schedule as `lr_t` but crucially will not be scaled by `lr`.
 
-    The standard `AdamW <https://pytorch.org/docs/stable/generated/torch.optim.AdamW.html#torch.optim.AdamW>`_
+    Argument defaults are similar to :class:`torch.optim.AdamW` but we make two changes:
+    * The default for ``weight_decay`` is changed from ``1e-2`` -> ``1e-5`` because in `DecoupledAdamW`, the weight decay is decoupled and no longer scaled by the `lr=1e-3`.
+    * The default for ``betas`` is changed from ``(0.9, 0.999)`` to ``(0.9, 0.95)`` to reflect community best-practices for the beta2 hyperparameter.
+
+    Why use this optimizer? The standard `AdamW <https://pytorch.org/docs/stable/generated/torch.optim.AdamW.html#torch.optim.AdamW>`_
     optimizer explicitly couples the weight decay term with the learning rate. This ties the
     optimal value of :attr:`weight_decay` to :attr:`lr` and can also hurt generalization in practice. For more details on
     why decoupling might be desirable, see `Decoupled Weight Decay Regularization <https://arxiv.org/abs/1711.05101>`_.
 
     Args:
-        params (list): List of parameters to update.
+        params (iterable): Iterable of parameters to optimize or dicts defining parameter groups.
         lr (float, optional): Learning rate. Default: ``1e-3``.
         betas (tuple, optional): Coefficients used for computing running averages of gradient and its square
-                                 Default: ``(0.9, 0.999)``.
+                                 Default: ``(0.9, 0.95)``.
         eps (float, optional): Term added to the denominator to improve numerical stability. Default: ``1e-8``.
-        weight_decay (float, optional): Decoupled weight decay factor. Default: ``1e-2``.
+        weight_decay (float, optional): Decoupled weight decay factor. Default: ``1e-5``.
         amsgrad (bool, optional): Enables the amsgrad variant of Adam. Default: ``False``.
     """
 
+    def __init__(self,
+                 params: Union[Iterable[torch.Tensor], Iterable[dict]],
+                 lr: float = 1e-3,
+                 betas: Tuple[float, float] = (0.9, 0.95),
+                 eps: float = 1e-8,
+                 weight_decay: float = 1e-5,
+                 amsgrad: bool = False):
+        if weight_decay >= 1e-3:
+            log.warning(
+                f'You are using a high value of `weight_decay={weight_decay}` for the `DecoupledAdamW` optimizer. Are you sure you want to do this? '
+                f'Your model\'s weights will be multiplied by {1.0 - weight_decay} on every step!')
+        super().__init__(params=params, lr=lr, betas=betas, eps=eps, weight_decay=weight_decay, amsgrad=amsgrad)
+        for group in self.param_groups:
+            group['initial_lr'] = group['lr']
+
     @staticmethod
     def adamw(params: List[torch.Tensor], grads: List[torch.Tensor], exp_avgs: List[torch.Tensor],
               exp_avg_sqs: List[torch.Tensor], max_exp_avg_sqs: List[torch.Tensor], state_steps: List[int], *,
@@ -174,12 +209,12 @@ class DecoupledAdamW(AdamW):
         r"""Functional API that performs AdamW algorithm computation with decoupled weight decay.
 
         Args:
-            params (List[torch.Tensor]): List of parameters to update.
-            grads (List[torch.Tensor]): List of parameter gradients.
-            exp_avgs (List[torch.Tensor]): List of average gradients.
-            exp_avg_sqs (List[torch.Tensor]): List of average squared gradients.
-            max_exp_avg_sqs (List[torch.Tensor]): List of max average squared gradients for amsgrad updates.
-            state_steps (Iterable[int]): List of steps taken for all parameters.
+            params (list): List of parameters to update.
+            grads (list): List of parameter gradients.
+            exp_avgs (list): List of average gradients.
+            exp_avg_sqs (list): List of average squared gradients.
+            max_exp_avg_sqs (list): List of max average squared gradients for amsgrad updates.
+            state_steps (list): List of steps taken for all parameters.
             amsgrad (bool): Enables amsgrad variant of Adam.
             beta1 (float): Coefficient for computing the moving average of gradient values.
             beta2 (float): Coefficient for computing the moving average of squared gradient values.
@@ -196,7 +231,7 @@ class DecoupledAdamW(AdamW):
 
             # Perform stepweight decay
             if weight_decay != 0:
-                decay_factor = lr / initial_lr
+                decay_factor = (lr / initial_lr) if initial_lr else 1.0
                 param.mul_(1 - decay_factor * weight_decay)
 
             bias_correction1 = 1 - beta1**step
@@ -217,17 +252,6 @@ class DecoupledAdamW(AdamW):
 
             param.addcdiv_(exp_avg, denom, value=-step_size)
 
-    def __init__(self,
-                 params: List[torch.Tensor],
-                 lr: float = 1e-3,
-                 betas: Tuple[float, float] = (0.9, 0.999),
-                 eps: float = 1e-8,
-                 weight_decay: float = 1e-2,
-                 amsgrad: bool = False):
-        super().__init__(params, lr, betas, eps, weight_decay, amsgrad)
-        for group in self.param_groups:
-            group['initial_lr'] = group['lr']
-
     @torch.no_grad()
     def step(self, closure=None):
         """Performs a single optimization step.
