@@ -14,9 +14,9 @@ from composer.trainer.devices.device import Device
 
 logger = logging.getLogger(__name__)
 
-__all__ = ["DeviceCPU"]
+__all__ = ['DeviceCPU']
 
-T_nnModule = TypeVar("T_nnModule", bound=torch.nn.Module)
+T_nnModule = TypeVar('T_nnModule', bound=torch.nn.Module)
 
 
 class DeviceCPU(Device):
@@ -25,7 +25,7 @@ class DeviceCPU(Device):
     This class takes no arguments.
     """
 
-    dist_backend = "gloo"
+    dist_backend = 'gloo'
     _device = torch.device('cpu')
 
     def module_to_device(self, module: T_nnModule) -> T_nnModule:
@@ -40,4 +40,4 @@ class DeviceCPU(Device):
 
     def load_state_dict(self, state: Dict[str, Any]) -> None:
         if len(state) != 0:
-            raise ValueError("CPU device has no state.")
+            raise ValueError('CPU device has no state.')
