@@ -7,13 +7,14 @@ import warnings
 from composer.utils.batch_helpers import batch_get, batch_set
 from composer.utils.checkpoint import load_checkpoint, save_checkpoint
 from composer.utils.collect_env import configure_excepthook, disable_env_report, enable_env_report, print_env
+from composer.utils.device import get_device, is_tpu_installed
 from composer.utils.file_helpers import (create_symlink_file, ensure_folder_has_no_conflicting_files,
                                          ensure_folder_is_empty, format_name_with_dist, format_name_with_dist_and_time,
                                          get_file, is_tar)
 from composer.utils.import_helpers import MissingConditionalImportError, import_object
 from composer.utils.inference import export_for_inference, export_with_logger, quantize_dynamic
 from composer.utils.iter_helpers import IteratorFileStream, ensure_tuple, map_collection
-from composer.utils.misc import is_model_deepspeed, is_notebook, model_eval_mode
+from composer.utils.misc import is_model_deepspeed, is_model_fsdp, is_notebook, model_eval_mode
 from composer.utils.object_store import (LibcloudObjectStore, ObjectStore, ObjectStoreTransientError, S3ObjectStore,
                                          SFTPObjectStore)
 from composer.utils.retrying import retry
@@ -51,6 +52,7 @@ __all__ = [
     'MissingConditionalImportError',
     'import_object',
     'is_model_deepspeed',
+    'is_model_fsdp',
     'is_notebook',
     'StringEnum',
     'load_checkpoint',
@@ -71,4 +73,6 @@ __all__ = [
     'print_env',
     'retry',
     'model_eval_mode',
+    'get_device',
+    'is_tpu_installed',
 ]
