@@ -5,6 +5,7 @@
 
 from __future__ import annotations
 
+import logging
 import os
 import pathlib
 import re
@@ -23,6 +24,8 @@ from composer.utils.object_store import ObjectStore
 if TYPE_CHECKING:
     from composer.loggers import LoggerDestination
 
+log = logging.getLogger(__name__)
+
 __all__ = [
     'get_file',
     'ensure_folder_is_empty',
@@ -358,6 +361,7 @@ def get_file(
             # Read object name in the symlink
             with open(symlink_file_name, 'r') as f:
                 real_path = f.read()
+                log.debug(f'Read path {real_path} from symlink file.')
 
         # Recurse
         return get_file(
@@ -411,8 +415,8 @@ def _get_file(
             )
         else:
             # Type LoggerDestination
-            object_store.get_file_artifact(
-                artifact_name=path,
+            object_store.download_file(
+                remote_file_name=path,
                 destination=destination,
                 progress_bar=progress_bar,
                 overwrite=overwrite,
@@ -484,7 +488,7 @@ def create_symlink_file(
     """Create a symlink file, which can be followed by :func:`get_file`.
 
     Unlike unix symlinks, symlink files can be created by this function are normal text files and can be
-    uploaded to object stores via :meth:`.ObjectStore.upload_object` or loggers via :meth:`.Logger.file_artifact`
+    uploaded to object stores via :meth:`.ObjectStore.upload_object` or loggers via :meth:`.Logger.upload_file`
     that otherwise would not support unix-style symlinks.
 
     Args:
@@ -494,8 +498,8 @@ def create_symlink_file(
     """
     # Loggers might not natively support symlinks, so we emulate symlinks via text files ending with `.symlink`
     # This text file contains the name of the object it is pointing to.
-    # Only symlink if we're logging artifact to begin with
-    # Write artifact name into file to emulate symlink
+    # Only symlink if we're uploading files to begin with
+    # Write remote file name into file to emulate symlink
     # Add .symlink extension so we can identify as emulated symlink when downloading
     destination_filename = str(destination_filename)
     if not destination_filename.endswith('.symlink'):
